Learn R Programming

cudaBayesreg (version 0.3-9)

cudaMultireg.volume: CUDA Parallel Implementation of a Bayesian Multilevel Model for fMRI Data Analysis on a fMRI NIFTI volume

Description

cudaMultireg.volume provides an interface to a CUDA implementation of a Bayesian multilevel model for the analysis of brain fMRI data. Data is processed on a slice-by-slice basis. Data volumes in gzipped NIFTI format are used.

Usage

cudaMultireg.volume(fbase="swrfM", R=2000, keep=5, nu.e=3,
  zprior=FALSE, rng=0, rg=c(NULL,NULL), swap=FALSE, savedir="/tmp")

Arguments

fbase
Indicates the data set prefix of the fMRI data set to use. The prefix applies to data files: {fbase}_filtered.nii.gz, {fbase}_mask.nii.gz, and {fbase}_design.txt. Two test data sets are included in the packag
R
number of MCMC draws
keep
MCMC thinning parameter: keep every keepth draw (def: 5)
nu.e
d.f. parameter for regression error variance prior (def: 3)
zprior
Boolean {T,F}; default {F} - use just a mean for Z (see model description in cudaMultireg.slice.
rng
integer {0,1,2}: type of RNG to use {0-Marsaglia Multicarry, 1-R. P. Brent xorgens, 2-Mersenne Twister MT19937-64}; (def. 0-Marsaglia Multicarry)
rg
rg=c(first, last): a vector containing the first and last numbers of the sequence of slices to be processed. If rg=c(NULL,NULL) (default), all slices in the volume are processed.
swap
logical variable (default = FALSE) for choosing the right/left data display convention consistent with FSLVIEW
savedir
Directory (def: "") were the MCMC simulations for all slices are going to be saved.

concept

  • bayes
  • MCMC
  • Gibbs Sampling
  • hierarchical models
  • linear model