Learn R Programming

cudaBayesreg (version 0.3-9)

post.shrinkage.minmax: Computes shrinkage of fitted estimates over regressions

Description

post.shrinkage.minmax computes the maximum and minimum fitted estimates, as a function of the mean regression coefficient estimates over all regressions.

Usage

post.shrinkage.minmax(out, X, vreg, plot=T)

Arguments

out
output of MCMC simulation
X
regression matrix used in the simulation
vreg
number of the regression coefficient
plot
{T,F} output plot (default=T)

Value

  • a list containing
  • yrecminminimum values of fitted values
  • yrecmaxmaximum values of fitted values
  • betamean of estimated coefficients over all regressions

Details

The plot helps visualizing shrinkage by analyzing the influence of the hyperparameter $nu$ on the dispersion of the fitted maximum and minimum estimates. Different shrinkage plots may be compared for simulations with different $nu$ values.

References

Adelino Ferreira da Silva, A Bayesian Multilevel Model for fMRI Data Analysis, Computer Methods and Programs in Biomedicine, to be published.

See Also

cudaMultireg.slice, read.fmrislice

Examples

Run this code
slicedata <- read.fmrislice(fbase="fmri", slice=3, swap=FALSE)
ymaskdata <- premask(slicedata)
fsave1 <- "/tmp/simultest1.sav"
nu1 <- 3
out <- cudaMultireg.slice(slicedata, ymaskdata, R=2000, keep=5, nu.e=nu1,
  fsave=fsave1, zprior=FALSE, rng=1)
vreg <- 2
post.shrinkage.minmax(out, slicedata$X, vreg=vreg)

Run the code above in your browser using DataLab