Learn R Programming

cudaBayesreg (version 0.3-13)

read.Zsegslice: Read brain segmented data based on structural regions for CSF, gray, and white matter.

Description

read.Zsegslice builds the Z matrix of the statistical model, based on the brain segmented regions CSF/GRY/WHT for a given fMRI dataset.

Usage

read.Zsegslice(slicedata, ymaskdata)

Arguments

Value

Zcentered matrix specifying the characteristics of cross-sectional units (optional group information)

concept

Read group information (Z data) for random effects estimation based on three brain segmented regions: CSF, gray and white matter.

Details

The FSL tools may be used to obtain the segmented masks for brain parcellation in three main regions according to tissue type (CSF,GRY,WHT). If fbase has been left unspecified in reading slicedata, then three user specified segmented datasets in gzipped NIFTI format must be provided as input, with the names csf.nii.gz, gry.nii.gz, and wht.nii.gz. Otherwise, fbase indicates the dataset prefix of one of the three segmented masks provided as a group effects example for swrfM_filtered_func_data.nii.gz: swrfM_csf.nii.gz, swrfM_gry.nii.gz, and swrfM_wht. Only swrfM segmented masks are provided in cudaBayesregData. The segmented masks included in the package were obtained by applying FAST to the structural high-resolution image sM00223*, followed by FLIRT for low-resolution registration to fM00223*. The sM00223* and fM00223* datasets are available from the SPM site, and are described in chapter 28 of the SPM8 manual. The fMRI dataset swrfM_filtered_func_data.nii.gz is a filtered version of fM00223*.

References

Adelino Ferreira da Silva (2011). cudaBayesregData: Data sets for the examples used in the package cudaBayesreg, R package version 0.3-10. URL http://CRAN.R-project.org/package=cudaBayesregData. FSL/FEAT Analysis tool, FMRIB Software Library (FSL). URL www.fmrib.ox.ac.uk/fsl. John Ashburner et. al.. SPM8 Manual, Functional Imaging Laboratory, Institute of Neurology, UCL, London. URL http://www.fil.ion.ucl.ac.uk/spm/.

See Also

cudaMultireg.slice, post.randeff, premask, post.ppm

Examples

Run this code
fbase <- "swrfM"
slice <- 21
slicedata <- read.fmrislice(fbase=fbase, slice=slice, swap=FALSE )
ymaskdata <- premask(slicedata)
Z <- read.Zsegslice(slicedata, ymaskdata )
## Random effects simulation
fsave <- paste(tempdir(),"/simultest2",fileext = ".sav", sep="")
out <- cudaMultireg.slice(slicedata, ymaskdata, R=2000, keep=5, nu.e=3,
  fsave=fsave, zprior=TRUE)
post.ppm(out=out, slicedata=slicedata, ymaskdata=ymaskdata, vreg=2)

Run the code above in your browser using DataLab