Learn R Programming

cudaBayesreg (version 0.3-10)

read.fmrislice: Read fMRI data

Description

read.fmrislice reads pre-filtered fMRI data, mask data, and the design matrix to be used in fMRI data processing.

Usage

read.fmrislice(fbase=NULL, slice=NULL, swap=FALSE)

Arguments

Value

a list containingfbasedataset prefix of the dataset used in the analysissliceslice numberniislicetsslice data at all timepointsmaskslice maskXfull design matrixnvarnumber of regression variablesnobsnumber of observationsswaprelative orientation used in the data setup

concept

read fmri data

Details

The FSL/FEAT Analysis tool may be used to generate the prefiltered fMRI data (niislicets), the mask (mask), and the design matrix (dsgn) required as data input. The FSL-design file design.mat is simply a ASCII textfile with the fields /NumWaves, /NumPoints, /PPheights, and /Matrix. Therefore, it may easily edited, if required, to prepare user specific design matrices without the FSL/FEAT tool. The package oro.nifti is required for reading gzipped NIFTI files.

References

FSL/FEAT Analysis tool, FMRIB Software Library (FSL) (www.fmrib.ox.ac.uk/fsl) Brandon Whitcher, Volker Schmid and Andrew Thornton (2011), R package oro.nifti: Rigorous - NIfTI Input / Output, R package version 0.2.5, http://CRAN.R-project.org/package=oro.nifti.

See Also

cudaMultireg.slice read.Zsegslice premask

Examples

Run this code
slicedata <- read.fmrislice(fbase="fmri", slice=3)
print(str(slicedata))

Run the code above in your browser using DataLab