Usage
buildzstat.volume(fbase="swrfM", vreg=2, nu.e=3, rg=c(NULL,NULL),
swap=FALSE, blobsize=3, savedir="/tmp")
Arguments
fbase
Indicates the data set prefix of the fMRI data set to use.
The prefix applies to data files: {fbase}_filtered.nii.gz,
{fbase}_mask.nii.gz, and {fbase}_design.txt.
Two test data sets are included in the packag
vreg
regression variable to represent in PPM; default(vreg=2)
nu.e
d.f. parameter for regression error variance prior (def: 3)
rg
rg=c(first, last): a vector containing the first and last
numbers of the sequence of slices to be processed.
If rg=c(NULL,NULL) (default), all slices in the volume are processed.
swap
logical variable (default = FALSE) for choosing the
right/left data display convention consistent with FSLVIEW
blobsize
numeric value (default=3). Applies spatial contextual
information in a 3D immediate neighbourhood for eliminating 3D blobs
with less than blobsize active voxels.
savedir
Directory (def: "") were the MCMC simulations for all
slices are saved.