mask: Example of mask file used in processing the visual-auditory test dataset
Description
The fmri_mask.nii.gz dataset defines the mask used in the fMRI analysis for fmri_filtered_data.nii.gz.
The mask used here is an all-brain mask; it just removes non-brain regions, as the result of applying a brain extraction tool to the fmri.nii.gz dataset.
However, other masks may be defined to select regions of interest (ROIs).Usage
fsl.mask <- system.file("data/fmri_mask.nii.gz",
package = "cudaBayesreg")
mask <- f.read.nifti.slice(file = fsl.mask, sl = 3, 1)docType
dataformat
The file fmri_mask.nii.gz is in ungzipped NIFTI format.
The R-package dcemri is required by cudaBayesreg to read gunzipped NIFTI files.
This file may be obtained from fmri.nii.gz by applying FSL/FEAT of FSL/BET pre-processing tools.
Similar preparation procedures for fMRI datasets are available in the SPM toolbox (http://www.fil.ion.ucl.ac.uk/spm/).References
S.M. Smith et.al., Advances in functional and structural MR image analysis and implementation as FSL. NeuroImage, 23(S1):208-219, 2004.
FSL & FreeSurfer Course, Oxford Centre for Functional Magnetic Resonance Imaging of the Brain (FMRIB), University of Oxford.
(www.fmrib.ox.ac.uk/fsl).