Learn R Programming

cudaBayesreg (version 0.3-9)

read.fmrislice: Read fMRI data

Description

read.fmrislice reads pre-filtered fMRI data, mask data, and the design matrix to be used in fMRI data processing.

Usage

read.fmrislice(fbase, slice, swap=FALSE)

Arguments

fbase
Indicates the dataset prefix of the fMRI dataset to use. The prefix applies to data files: {fbase}_filtered.nii.gz, {fbase}_mask.nii.gz, and {fbase}_design.txt. Two test datsets are included in the package; on
slice
The number of the slice to use.
swap
logical variable (default = FALSE) for choosing the right/left data display convention consistent with FSLVIEW

Value

  • a list containing
  • fbasedataset prefix of the dataset used in the analysis
  • sliceslice number
  • niislicetsslice data at all timepoints
  • maskslice mask
  • Xfull design matrix
  • nvarnumber of regression variables
  • nobsnumber of observations
  • swaprelative orientation used in the data setup

concept

read fmri data

Details

The FSL/FEAT Analysis tool may be used to generate the prefiltered fMRI data (niislicets), the mask (mask), and the design matrix (dsgn) required as data input. The package oro.nifti is required for reading gzipped NIFTI files.

References

Brandon Whitcher, Volker Schmid and Andrew Thornton, Package oro.nifti: Rigorous - NIfTI Input / Output, 2010. FSL/FEAT Analysis tool, FMRIB Software Library (FSL) (www.fmrib.ox.ac.uk/fsl)

See Also

cudaMultireg.slice premask

Examples

Run this code
slicedata <- read.fmrislice(fbase="fmri", slice=3)
print(str(slicedata))

Run the code above in your browser using DataLab