a list containingfbasedataset prefix of the dataset used in the analysissliceslice numberniislicetsslice data at all timepointsmaskslice maskXfull design matrixnvarnumber of regression variablesnobsnumber of observationsswaprelative orientation used in the data setup
concept
read fmri data
Details
The FSL/FEAT Analysis tool may be used to generate the prefiltered fMRI data
(niislicets), the mask (mask), and the design matrix (dsgn) required as data input.
The FSL-design file design.mat is simply a ASCII textfile with the fields
/NumWaves, /NumPoints, /PPheights, and /Matrix.
Therefore, it may easily edited, if required, to prepare user specific design matrices
without the FSL/FEAT tool.
The package oro.nifti is required for reading gzipped NIFTI files.
References
Adelino Ferreira da Silva (2011). cudaBayesregData: Data sets for the examples used in the package cudaBayesreg, R package version 0.3-10.
URL http://CRAN.R-project.org/package=cudaBayesregData.
FSL/FEAT Analysis tool, FMRIB Software Library (FSL). URL www.fmrib.ox.ac.uk/fsl.
Brandon Whitcher, Volker Schmid and Andrew Thornton (2011). oro.nifti: Rigorous - NIfTI Input / Output, R package version 0.2.5.
URL http://CRAN.R-project.org/package=oro.nifti.